@@ -46,7 +46,7 @@ pressure_read(struct tslib_module_info *info, struct ts_sample *samp, int nr)
 	return ret;
 }
 
-static int pressure_fini(struct tslib_module_info *info)
+static void pressure_fini(struct tslib_module_info *info)
 {
 	free(info);
 }
