@@ -26,7 +26,7 @@ struct tslib_vars {
 
 struct tslib_ops {
 	int (*read)(struct tslib_module_info *inf, struct ts_sample *samp, int nr);
-	int (*fini)(struct tslib_module_info *inf);
+	void (*fini)(struct tslib_module_info *inf);
 };
 
 struct tslib_module_info {
